@@ -278,7 +278,7 @@ echo -e "\n\n---> Created control.NEW..."
 echo -e "\n\n---> Creating forensics-extra.README.Debian.NEW..."
 echo "forensics-extra for Debian" > forensics-extra.README.Debian.NEW
 echo "--------------------------" >> forensics-extra.README.Debian.NEW
-echo -e "\nLIST OF PACKAGES INSTALLED BY forensics-extra DEBIAN PACKAGE" >> forensics-extra.README.Debian.NEW
+echo -e "\nLIST OF PACKAGES INSTALLED BY forensics-extra" >> forensics-extra.README.Debian.NEW
 echo -e "\n\nCOMMON PACKAGES (available for all machines)\n"  >> forensics-extra.README.Debian.NEW
 ./synopsis.sh FED >> forensics-extra.README.Debian.NEW
 echo -e "\nRECOMMENDED PACKAGES (available for some architectures only)\n" >> forensics-extra.README.Debian.NEW
@@ -300,7 +300,7 @@ echo " -- $DEBFULLNAME <$DEBEMAIL>  $(LANG=C date -R)" >> forensics-extra.README
 echo -e "\n\n---> Creating forensics-extra-gui.README.Debian.NEW..."
 echo "forensics-extra-gui for Debian" > forensics-extra-gui.README.Debian.NEW
 echo "------------------------------" >> forensics-extra-gui.README.Debian.NEW
-echo -e "\nLIST OF PACKAGES INSTALLED BY forensics-extra-gui DEBIAN PACKAGE" >> forensics-extra-gui.README.Debian.NEW
+echo -e "\nLIST OF PACKAGES INSTALLED BY forensics-extra-gui" >> forensics-extra-gui.README.Debian.NEW
 echo -e "\n\nCOMMON PACKAGES (available for all machines)\n"  >> forensics-extra-gui.README.Debian.NEW
 ./synopsis.sh FGD >> forensics-extra-gui.README.Debian.NEW
 echo -e "\nRECOMMENDED PACKAGES (available for some architectures only)\n" >> forensics-extra-gui.README.Debian.NEW
